bluemath\_tk.topo\_bathy package
================================

Submodules
----------

bluemath\_tk.topo\_bathy.profiles module
----------------------------------------

.. automodule:: bluemath_tk.topo_bathy.profiles
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.topo\_bathy.swan\_grid module
------------------------------------------

.. automodule:: bluemath_tk.topo_bathy.swan_grid
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.topo_bathy
   :members:
   :undoc-members:
   :show-inheritance:
